@@ -418,16 +418,13 @@ impl BucketSelect {
         let mut buffer = String::default();
 
         if body_bytes.is_empty() {
-            warn!(
-                slog_scope::logger(),
-                "The response body of the bucket select is empty"
-            );
+            warn!("The response body of the bucket select is empty");
             return Ok(buffer);
         }
 
-        debug!(slog_scope::logger(),
-            "Data fetch from the bucket";
-            "data" => String::from_utf8_lossy(&body_bytes).to_string(),
+        trace!(
+            data = String::from_utf8_lossy(&body_bytes).to_string().as_str(),
+            "Data fetch from the bucket"
         );
 
         let mut event_stream =
@@ -506,16 +503,13 @@ impl BucketSelect {
         let mut buffer: usize = 0;
 
         if body_bytes.is_empty() {
-            warn!(
-                slog_scope::logger(),
-                "The response body of the bucket select is empty"
-            );
+            warn!("The response body of the bucket select is empty");
             return Ok(buffer);
         }
 
-        debug!(slog_scope::logger(),
-            "Data fetch from the bucket";
-            "data" => String::from_utf8_lossy(&body_bytes).to_string(),
+        trace!(
+            data = String::from_utf8_lossy(&body_bytes).to_string().as_str(),
+            "Data fetch from the bucket"
         );
 
         let mut event_stream =
@@ -660,7 +654,10 @@ impl Connector for BucketSelect {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn len(&mut self) -> Result<usize> {
+        trace!("Start");
+        
         let mut connector = self.clone();
         connector.query = format!(
             "{} {}",
@@ -739,7 +736,10 @@ impl Connector for BucketSelect {
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn fetch(&mut self) -> Result<()> {
+        trace!("Start");
+
         if let (Some(true), Some("csv")) = (
             self.metadata().has_headers,
             self.metadata().mime_subtype.as_deref(),
@@ -901,21 +901,24 @@ impl Paginator for BucketSelectPaginator {
     ///     connector.access_key_id = Some("minio_access_key".to_string());
     ///     connector.secret_access_key = Some("minio_secret_key".to_string());
     ///     connector.bucket = "my-bucket".to_string();
-    ///     connector.path = "data/*.json".to_string();
+    ///     connector.path = "data/*.json$".to_string();
     ///     connector.query = "select * from s3object".to_string();
     ///     connector.limit = Some(5);
-    ///     connector.skip = 2;
+    ///     connector.skip = 1;
     ///     connector.metadata = Metadata {
     ///         ..Json::default().metadata
     ///     };
     ///     let mut paginator = connector.paginator().await?;
-    ///     assert_eq!("data/multi_lines.jsonl".to_string(), paginator.next_page().await?.unwrap().path());
+    ///     assert_eq!("data/multi_lines.json".to_string(), paginator.next_page().await?.unwrap().path());
     ///     assert_eq!("data/one_line.json".to_string(), paginator.next_page().await?.unwrap().path());
     ///
     ///     Ok(())
     /// }
     /// ```
+    #[instrument]
     async fn next_page(&mut self) -> Result<Option<Box<dyn Connector>>> {
+        trace!("Start");
+
         let mut connector = self.connector.clone();
 
         for path in &mut self.paths {
@@ -923,7 +926,11 @@ impl Paginator for BucketSelectPaginator {
             match connector.fetch().await {
                 Ok(_) => (),
                 Err(e) => {
-                    warn!(slog_scope::logger(), "The paginator skip the resource due to an error"; "error" => e, "connector" => format!("{:?}", connector));
+                    warn!(
+                        error = e.to_string().as_str(),
+                        connector = format!("{:?}", connector).as_str(),
+                        "The paginator skip the resource due to an error"
+                    );
                     continue;
                 }
             };
